# gastby-plugin-nebo

A Gatsby plugin that sources data from Nebo, the visual React builder.

The plugin: 
1. Creates pages for all of your Nebo pages.
2. Creates `Nodes` for all of your Nebo components. These can be queried through `useStaticQuery`.

## Table of Contents
- [Install](#install)
- [How to use](#how-to-use)
  - [Adding your components](#adding-your-components)
  - [Adding your styles](#adding-your-styles)
  - [Configuration Options](#configuration-options)

## Install
1. Sign up for [Nebo](https://app.nebohq.com/users/sign_up). After you've signed in, navigate to "Settings" on the side bar.

2. Find and copy the access token. You can find it in the "Developers" section:![Access Token](https://res.cloudinary.com/hzimreaxl/image/upload/v1622158327/setup-developers.png)

3. Set up the plugin in your `gatsby-config.js`, adding in your access token:

```js
module.exports = {
  plugins: [
    ...otherPlugins,
    {
      resolve: 'gatsby-plugin-nebo',
      // make sure to provide your access token below!
      options: { accessToken: '[YOUR ACCESS KEY HERE]' },
    },
  ],
};
```

4. Install `gatsby-plugin-nebo` and `@nebohq/nebo`:
```shell
# if you are using npm and package-lock.json
npm install gatsby-plugin-nebo @nebohq/nebo
# if you are using yarn and yarn.lock
yarn add gatsby-plugin-nebo @nebohq/nebo
```

5. You're now ready to build pages in Nebo! [Follow our guide on building pages here](#TBD).

The last step will generate a configuration (`./src/config/nebo-config.js`) and the page template (`./src/templates/nebo-page.js`). 
If you have filled in your access token in `gatsby-config.js`, it will automatically be added to the configuration.

## How to use
### Adding your components
1. On the Nebo website, navigate to "Developer" settings in the Nebo App.
   Add `[YOUR_PRODUCTION_URL]/nebo-config.js`<sup>1</sup> or `[YOUR_DEVELOPMENT_URL]/nebo.js`<sup>2</sup> to "Javascript Source URL".
2. If you are using the production URL, make sure you have deployed your app at least once with `gatsby-plugin-nebo` installed for the URL to become available.
3. In your code, navigate to `./src/config/nebo-config.js` (or your `configPath`). Add your components in the indicated space.
```js
import { configure } from '@nebohq/nebo';
import React from 'react';
import ReactDOM from 'react-dom';
import { Nav, Container, Row, Col } from 'react-bootstrap';
import { Linkedin } from 'react-bootstrap-icons';

const directory = configure({
  directory: {
    // ADD YOUR COMPONENTS HERE
    Nav,
    Icons: { LinkedIn },
    Bootstrap: { Layout: { Container, Row, Col } }
  },
  react: React,
  renderer: ReactDOM,
  accessToken: '[YOUR_ACCESS_TOKEN]'
});

export default directory;
```
4. Deploy your Gatsby app. If you are using you local development url, switch it your production one first!
5. Once your deploy is complete, your components will be available in the Nebo editor.

<sup>1</sup> If you have changed the `configPath`, the URL will be: `[YOUR_PRODUCTION_URL]/[CONFIG_PATH_FILE_NAME].js`.

<sup>2</sup> Usually, the development URL will be `http://localhost:8000/nebo-config.js`.
If your `configPath` has been changed, it will be `http://localhost:8000/[CONFIG_PATH_FILE_NAME].js`. 

### Adding your styles
1. On the Nebo website, navigate to "Developer" settings in the Nebo App. 
   Add `[YOUR_PRODUCTION_URL]/nebo-config.css`<sup>1</sup> or `[YOUR_DEVELOPMENT_URL]/nebo.css`<sup>2</sup> to CSS Source URL.
2. If you are using the production URL, make sure you have deployed your app at least once with `gatsby-plugin-nebo` installed for the URL to become available.
3. In your code, navigate to `./src/config/nebo-config.js` (or your `configPath`). Add your styles in the indicated space:
```js
import { configure } from '@nebohq/nebo';
import React from 'react';
import ReactDOM from 'react-dom';
import { Nav, Container, Row, Col } from 'react-bootstrap';
import { Linkedin } from 'react-bootstrap-icons';
// ADD YOUR STYLES HERE
import 'bootstrap/dist/css/bootstrap.min.css';
import '../src/components/directory.module.scss';

const directory = configure({ 
  // OPTIONS
});

export default directory;
```
4. Deploy your Gatsby app. If you are using you local development url, switch it your production one first!
5. Once your deploy is complete, your styles will be available in the Nebo editor.

<sup>1</sup> If you have changed the `configPath`, the URL will be: `[YOUR_PRODUCTION_URL]/[CONFIG_PATH_FILE_NAME].css`.

<sup>2</sup> Usually, the development URL will be `http://localhost:8000/nebo-config.css`. 
If your `configPath` has been changed, it will be `http://localhost:8000/[CONFIG_PATH_FILE_NAME].css`.

### Configuration Options
```js
module.exports = {
  plugins: [
    ...otherPlugins,
    {
      resolve: 'gatsby-plugin-nebo',
      options: { 
        accessToken: '[ACCESS_KEY]',
        configPath: `${__dirname}/src/config/nebo-config.js`, // path to the configruation file
        pageTemplatePath: `${__dirname}/src/templates/nebo-page.js`, // path to the page template
        ignoredPageSlugs: [] // list of page slugs you want to ignore
      },
    },
  ],
};
```

- `accessToken` - [required] - used to access your components from your Gatsby app.
- `configPath` - path to the the Nebo configuration file. This controls which of your components are available in the Nebo editor.
- `pageTemplatePath` - path to the Nebo page template. This controls the look of your pages.
- `ignoredPageSlugs` - list of pages to ignore, by their Nebo slug.

